/* ANSI-C code produced by gperf version 3.1 */
/* Command-line: gperf --output-file src/network/networkd-network-gperf.c ../git/src/network/networkd-network-gperf.gperf  */
/* Computed positions: -k'1,6-7,11-12,16,20,24,29,$' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
#endif

#line 2 "../git/src/network/networkd-network-gperf.gperf"

#if __GNUC__ >= 7
_Pragma("GCC diagnostic ignored \"-Wimplicit-fallthrough\"")
#endif
#include <stddef.h>
#include "conf-parser.h"
#include "in-addr-prefix-util.h"
#include "netem.h"
#include "net-condition.h"
#include "networkd-address-generation.h"
#include "networkd-address-label.h"
#include "networkd-address.h"
#include "networkd-bridge-fdb.h"
#include "networkd-bridge-mdb.h"
#include "networkd-can.h"
#include "networkd-dhcp-common.h"
#include "networkd-dhcp-prefix-delegation.h"
#include "networkd-dhcp-server-static-lease.h"
#include "networkd-dhcp-server.h"
#include "networkd-dhcp4.h"
#include "networkd-dhcp6.h"
#include "networkd-ipv4ll.h"
#include "networkd-ipv6-proxy-ndp.h"
#include "networkd-ipv6ll.h"
#include "networkd-lldp-tx.h"
#include "networkd-ndisc.h"
#include "networkd-network.h"
#include "networkd-neighbor.h"
#include "networkd-nexthop.h"
#include "networkd-radv.h"
#include "networkd-route.h"
#include "networkd-routing-policy-rule.h"
#include "networkd-sriov.h"
#include "qdisc.h"
#include "tclass.h"
#include "vlan-util.h"
#include <string.h>

#define TOTAL_KEYWORDS 533
#define MIN_WORD_LENGTH 8
#define MAX_WORD_LENGTH 69
#define MIN_HASH_VALUE 20
#define MAX_HASH_VALUE 2539
/* maximum key range = 2520, duplicates = 0 */

#ifdef __GNUC__
__inline
#else
#ifdef __cplusplus
inline
#endif
#endif
static unsigned int
network_network_gperf_hash (register const char *str, register size_t len)
{
  static const unsigned short asso_values[] =
    {
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540,   25,    5, 2540,   35,
        10,   30,  245, 2540,  460, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540,  415,  280,   80,    5,  500,
       165,  335,  500,  345, 2540,   30,  480,   70,   15,   80,
        10,  540,  110,    0,  165,  820,  665,   70, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540,    0,   25,   35,
       360,    0,  115,   20,  635,   20, 2540,    5,    0,  695,
         0,   50,  645, 2540,   45,    5,    5,   10,  440,   50,
        35,  180,   25, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540, 2540,
      2540, 2540, 2540, 2540, 2540, 2540
    };
  register unsigned int hval = len;

  switch (hval)
    {
      default:
        hval += asso_values[(unsigned char)str[28]];
      /*FALLTHROUGH*/
      case 28:
      case 27:
      case 26:
      case 25:
      case 24:
        hval += asso_values[(unsigned char)str[23]];
      /*FALLTHROUGH*/
      case 23:
      case 22:
      case 21:
      case 20:
        hval += asso_values[(unsigned char)str[19]];
      /*FALLTHROUGH*/
      case 19:
      case 18:
      case 17:
      case 16:
        hval += asso_values[(unsigned char)str[15]];
      /*FALLTHROUGH*/
      case 15:
      case 14:
      case 13:
      case 12:
        hval += asso_values[(unsigned char)str[11]];
      /*FALLTHROUGH*/
      case 11:
        hval += asso_values[(unsigned char)str[10]];
      /*FALLTHROUGH*/
      case 10:
      case 9:
      case 8:
      case 7:
        hval += asso_values[(unsigned char)str[6]];
      /*FALLTHROUGH*/
      case 6:
        hval += asso_values[(unsigned char)str[5]];
      /*FALLTHROUGH*/
      case 5:
      case 4:
      case 3:
      case 2:
      case 1:
        hval += asso_values[(unsigned char)str[0]];
        break;
    }
  return hval + asso_values[(unsigned char)str[len - 1]];
}

const struct ConfigPerfItem *
network_network_gperf_lookup (register const char *str, register size_t len)
{
  static const struct ConfigPerfItem wordlist[] =
    {
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 499 "../git/src/network/networkd-network-gperf.gperf"
      {"PIE.Handle",                                  config_parse_qdisc_handle,                                QDISC_KIND_PIE,                0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 431 "../git/src/network/networkd-network-gperf.gperf"
      {"PFIFO.Parent",                                config_parse_qdisc_parent,                                QDISC_KIND_PFIFO,              0},
      {(char*)0}, {(char*)0},
#line 498 "../git/src/network/networkd-network-gperf.gperf"
      {"PIE.Parent",                                  config_parse_qdisc_parent,                                QDISC_KIND_PIE,                0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 116 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DNS",                                 config_parse_dns,                                         0,                             0},
      {(char*)0}, {(char*)0},
#line 100 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.Tunnel",                              config_parse_stacked_netdev,                              _NETDEV_KIND_TUNNEL,           offsetof(Network, stacked_netdev_names)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 341 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.Announce",               config_parse_bool,                                        0,                             offsetof(Network, dhcp_pd_announce)},
      {(char*)0},
#line 344 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.Token",                  config_parse_address_generation_type,                     0,                             offsetof(Network, dhcp_pd_tokens)},
#line 342 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.Assign",                 config_parse_bool,                                        0,                             offsetof(Network, dhcp_pd_assign)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 339 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.UplinkInterface",        config_parse_uplink,                                      0,                             0},
#line 433 "../git/src/network/networkd-network-gperf.gperf"
      {"PFIFO.PacketLimit",                           config_parse_pfifo_size,                                  QDISC_KIND_PFIFO,              0},
      {(char*)0},
#line 288 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.DNS",                              config_parse_dhcp_server_emit,                            0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_DNS])},
#line 119 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.MulticastDNS",                        config_parse_resolve_support,                             0,                             offsetof(Network, mdns)},
#line 123 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.NTP",                                 config_parse_ntp,                                         0,                             offsetof(Network, ntp)},
      {(char*)0}, {(char*)0},
#line 292 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.SIP",                              config_parse_dhcp_server_emit,                            0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_SIP])},
#line 296 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.SMTP",                             config_parse_dhcp_server_emit,                            0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_SMTP])},
#line 385 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.OneShot",                                 config_parse_can_control_mode,                            CAN_CTRLMODE_ONE_SHOT,         0},
#line 111 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.LLDP",                                config_parse_lldp_mode,                                   0,                             offsetof(Network, lldp_mode)},
#line 343 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.ManageTemporaryAddress", config_parse_bool,                                        0,                             offsetof(Network, dhcp_pd_manage_temporary_address)},
#line 304 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.PoolSize",                         config_parse_uint32,                                      0,                             offsetof(Network, dhcp_server_pool_size)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 135 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.ActiveSlave",                         config_parse_bool,                                        0,                             offsetof(Network, active_slave)},
#line 57 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.SSID",                                  config_parse_match_strv,                                  0,                             offsetof(Network, match.ssid)},
#line 399 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.Parent",                                 config_parse_qdisc_parent,                                QDISC_KIND_CAKE,               0},
      {(char*)0}, {(char*)0},
#line 290 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.NTP",                              config_parse_dhcp_server_emit,                            0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_NTP])},
      {(char*)0},
#line 367 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.BitRate",                                 config_parse_can_bitrate,                                 0,                             offsetof(Network, can_bitrate)},
#line 491 "../git/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.Parent",                      config_parse_qdisc_parent,                                QDISC_KIND_NETEM,              0},
      {(char*)0},
#line 495 "../git/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.LossRate",                    config_parse_network_emulator_rate,                       QDISC_KIND_NETEM,              0},
#line 59 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Name",                                  config_parse_match_ifnames,                               IFNAME_VALID_ALTERNATIVE,      offsetof(Network, match.ifname)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 496 "../git/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.DuplicateRate",               config_parse_network_emulator_rate,                       QDISC_KIND_NETEM,              0},
      {(char*)0},
#line 112 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.EmitLLDP",                            config_parse_lldp_multicast_mode,                         0,                             offsetof(Network, lldp_multicast_mode)},
      {(char*)0}, {(char*)0},
#line 87 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.Description",                         config_parse_string,                                      0,                             offsetof(Network, description)},
#line 294 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.POP3",                             config_parse_dhcp_server_emit,                            0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_POP3])},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 345 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.RouteMetric",            config_parse_uint32,                                      0,                             offsetof(Network, dhcp_pd_route_metric)},
      {(char*)0},
#line 381 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.RestartSec",                              config_parse_can_restart_usec,                            0,                             offsetof(Network, can_restart_us)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 391 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.Termination",                             config_parse_can_termination,                             0,                             0},
#line 185 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.Scope",                                 config_parse_route_scope,                                 0,                             0},
#line 497 "../git/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.PacketLimit",                 config_parse_network_emulator_packet_limit,               QDISC_KIND_NETEM,              0},
      {(char*)0},
#line 64 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.KernelVersion",                         config_parse_net_condition,                               CONDITION_KERNEL_VERSION,      offsetof(Network, conditions)},
#line 142 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IgnoreCarrierLoss",                   config_parse_ignore_carrier_loss,                         0,                             0},
      {(char*)0}, {(char*)0},
#line 117 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DNSDefaultRoute",                     config_parse_tristate,                                    0,                             offsetof(Network, dns_default_route)},
      {(char*)0},
#line 125 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPMasquerade",                        config_parse_ip_masquerade,                               0,                             offsetof(Network, ip_masquerade)},
#line 545 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.RequestBroadcast",                       config_parse_tristate,                                    0,                             offsetof(Network, dhcp_broadcast)},
      {(char*)0}, {(char*)0},
#line 121 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DNSSEC",                              config_parse_dnssec_mode,                                 0,                             offsetof(Network, dnssec_mode)},
#line 494 "../git/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.DelayJitterSec",              config_parse_network_emulator_delay,                      QDISC_KIND_NETEM,              0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 387 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.FDMode",                                  config_parse_can_control_mode,                            CAN_CTRLMODE_FD,               0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 122 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DNSSECNegativeTrustAnchors",          config_parse_dnssec_negative_trust_anchors,               0,                             offsetof(Network, dnssec_negative_trust_anchors)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 104 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DHCP",                                config_parse_dhcp,                                        0,                             offsetof(Network, dhcp)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 183 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.Source",                                config_parse_destination,                                 0,                             0},
#line 404 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.MPUBytes",                               config_parse_cake_mpu,                                    QDISC_KIND_CAKE,               0},
#line 493 "../git/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.DelaySec",                    config_parse_network_emulator_delay,                      QDISC_KIND_NETEM,              0},
      {(char*)0},
#line 138 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.ProxyARP",                            config_parse_tristate,                                    0,                             offsetof(Network, proxy_arp)},
#line 413 "../git/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.Parent",                      config_parse_qdisc_parent,                                QDISC_KIND_CODEL,              0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 303 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.PoolOffset",                       config_parse_uint32,                                      0,                             offsetof(Network, dhcp_server_pool_offset)},
#line 409 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.PriorityQueueingPreset",                 config_parse_cake_priority_queueing_preset,               QDISC_KIND_CAKE,               0},
#line 546 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.CriticalConnection",                     config_parse_tristate,                                    0,                             offsetof(Network, dhcp_critical)},
#line 419 "../git/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.ECN",                         config_parse_controlled_delay_bool,                       QDISC_KIND_CODEL,              0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 97 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.MACsec",                              config_parse_stacked_netdev,                              NETDEV_KIND_MACSEC,            offsetof(Network, stacked_netdev_names)},
      {(char*)0}, {(char*)0},
#line 53 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Driver",                                config_parse_match_strv,                                  0,                             offsetof(Network, match.driver)},
#line 384 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.TripleSampling",                          config_parse_can_control_mode,                            CAN_CTRLMODE_3_SAMPLES,        0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 370 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.PropagationSegment",                      config_parse_uint32,                                      0,                             offsetof(Network, can_propagation_segment)},
#line 166 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.Table",                     config_parse_routing_policy_rule_table,                   0,                             0},
      {(char*)0},
#line 501 "../git/src/network/networkd-network-gperf.gperf"
      {"StochasticFairBlue.Parent",                   config_parse_qdisc_parent,                                QDISC_KIND_SFB,                0},
#line 434 "../git/src/network/networkd-network-gperf.gperf"
      {"PFIFOFast.Parent",                            config_parse_qdisc_parent,                                QDISC_KIND_PFIFO_FAST,         0},
      {(char*)0}, {(char*)0},
#line 446 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Handle",                         config_parse_qdisc_handle,                                QDISC_KIND_FQ,                 0},
#line 374 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.DataBitRate",                             config_parse_can_bitrate,                                 0,                             offsetof(Network, can_data_bitrate)},
      {(char*)0},
#line 415 "../git/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.PacketLimit",                 config_parse_controlled_delay_u32,                        QDISC_KIND_CODEL,              0},
#line 175 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.InvertRule",                config_parse_routing_policy_rule_invert,                  0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 417 "../git/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.IntervalSec",                 config_parse_controlled_delay_usec,                       QDISC_KIND_CODEL,              0},
#line 174 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.DestinationPort",           config_parse_routing_policy_rule_port_range,              0,                             0},
      {(char*)0}, {(char*)0},
#line 306 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.SendOption",                       config_parse_dhcp_send_option,                            0,                             offsetof(Network, dhcp_server_send_options)},
#line 182 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.Destination",                           config_parse_destination,                                 0,                             0},
#line 172 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.IPProtocol",                config_parse_routing_policy_rule_ip_protocol,             0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 505 "../git/src/network/networkd-network-gperf.gperf"
      {"StochasticFairnessQueueing.Handle",           config_parse_qdisc_handle,                                QDISC_KIND_SFQ,                0},
      {(char*)0},
#line 503 "../git/src/network/networkd-network-gperf.gperf"
      {"StochasticFairBlue.PacketLimit",              config_parse_stochastic_fair_blue_u32,                    QDISC_KIND_SFB,                0},
      {(char*)0},
#line 382 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.Loopback",                                config_parse_can_control_mode,                            CAN_CTRLMODE_LOOPBACK,         0},
#line 504 "../git/src/network/networkd-network-gperf.gperf"
      {"StochasticFairnessQueueing.Parent",           config_parse_qdisc_parent,                                QDISC_KIND_SFQ,                0},
      {(char*)0},
#line 416 "../git/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.TargetSec",                   config_parse_controlled_delay_usec,                       QDISC_KIND_CODEL,              0},
      {(char*)0},
#line 379 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.DataPhaseBufferSegment2",                 config_parse_uint32,                                      0,                             offsetof(Network, can_data_phase_buffer_segment_2)},
      {(char*)0},
#line 192 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.Protocol",                              config_parse_route_protocol,                              0,                             0},
#line 170 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.IncomingInterface",         config_parse_routing_policy_rule_device,                  0,                             0},
#line 186 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.PreferredSource",                       config_parse_preferred_src,                               0,                             0},
#line 300 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.Router",                           config_parse_in_addr_non_null,                            AF_INET,                       offsetof(Network, dhcp_server_router)},
      {(char*)0},
#line 456 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.Parent",          config_parse_qdisc_parent,                                QDISC_KIND_FQ_CODEL,           0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 458 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.PacketLimit",     config_parse_fair_queueing_controlled_delay_u32,          QDISC_KIND_FQ_CODEL,           0},
#line 171 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.OutgoingInterface",         config_parse_routing_policy_rule_device,                  0,                             0},
      {(char*)0},
#line 177 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.User",                      config_parse_routing_policy_rule_uid_range,               0,                             0},
      {(char*)0}, {(char*)0},
#line 452 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Buckets",                        config_parse_fair_queueing_u32,                           QDISC_KIND_FQ,                 0},
      {(char*)0},
#line 96 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.L2TP",                                config_parse_warn_compat,                                 DISABLED_LEGACY,               0},
      {(char*)0},
#line 445 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Parent",                         config_parse_qdisc_parent,                                QDISC_KIND_FQ,                 0},
#line 114 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.Gateway",                             config_parse_gateway,                                     0,                             0},
      {(char*)0},
#line 378 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.DataPhaseBufferSegment1",                 config_parse_uint32,                                      0,                             offsetof(Network, can_data_phase_buffer_segment_1)},
#line 173 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.SourcePort",                config_parse_routing_policy_rule_port_range,              0,                             0},
#line 454 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Pacing",                         config_parse_fair_queueing_bool,                          QDISC_KIND_FQ,                 0},
#line 54 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Type",                                  config_parse_match_strv,                                  0,                             offsetof(Network, match.iftype)},
#line 556 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.RapidCommit",                            config_parse_warn_compat,                                 DISABLED_LEGACY,               0},
#line 389 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.FDNonISO",                                config_parse_can_control_mode,                            CAN_CTRLMODE_FD_NON_ISO,       0},
#line 118 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.LLMNR",                               config_parse_resolve_support,                             0,                             offsetof(Network, llmnr)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 506 "../git/src/network/networkd-network-gperf.gperf"
      {"StochasticFairnessQueueing.PerturbPeriodSec", config_parse_stochastic_fairness_queueing_perturb_period, QDISC_KIND_SFQ,                0},
      {(char*)0}, {(char*)0},
#line 386 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.BusErrorReporting",                       config_parse_can_control_mode,                            CAN_CTRLMODE_BERR_REPORTING,   0},
      {(char*)0}, {(char*)0},
#line 302 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.Timezone",                         config_parse_timezone,                                    0,                             offsetof(Network, dhcp_server_timezone)},
#line 167 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.FirewallMark",              config_parse_routing_policy_rule_fwmark_mask,             0,                             0},
      {(char*)0},
#line 223 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.Label",                                config_parse_dhcp_label,                                  0,                             offsetof(Network, dhcp_label)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 222 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.Hostname",                             config_parse_hostname,                                    0,                             offsetof(Network, dhcp_hostname)},
#line 229 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.IAID",                                 config_parse_iaid,                                        AF_INET,                       0},
#line 233 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RouteTable",                           config_parse_dhcp_or_ra_route_table,                      AF_INET,                       0},
#line 145 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DHCPPrefixDelegation",                config_parse_tristate,                                    0,                             offsetof(Network, dhcp_pd)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 210 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RoutesToDNS",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_routes_to_dns)},
      {(char*)0},
#line 169 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.To",                        config_parse_routing_policy_rule_prefix,                  0,                             0},
      {(char*)0},
#line 184 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.Metric",                                config_parse_route_priority,                              0,                             0},
#line 209 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseDNS",                               config_parse_dhcp_use_dns,                                AF_INET,                       0},
      {(char*)0},
#line 193 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.Type",                                  config_parse_route_type,                                  0,                             0},
#line 187 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.Table",                                 config_parse_route_table,                                 0,                             0},
      {(char*)0}, {(char*)0},
#line 579 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.MemoryLimit",     config_parse_fair_queueing_controlled_delay_size,         QDISC_KIND_FQ_CODEL,           0},
#line 523 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DHCPv6PrefixDelegation",              config_parse_tristate,                                    0,                             offsetof(Network, dhcp_pd)},
      {(char*)0}, {(char*)0},
#line 110 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DefaultRouteOnDevice",                config_parse_bool,                                        0,                             offsetof(Network, default_route_on_device)},
#line 459 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.MemoryLimitBytes", config_parse_fair_queueing_controlled_delay_size,        QDISC_KIND_FQ_CODEL,           0},
#line 286 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.DefaultLeaseTimeSec",              config_parse_sec,                                         0,                             offsetof(Network, dhcp_server_default_lease_time_usec)},
#line 552 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.RouteMetric",                            config_parse_dhcp_or_ra_route_metric,                     AF_UNSPEC,                     0},
      {(char*)0},
#line 212 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RoutesToNTP",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_routes_to_ntp)},
#line 66 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Firmware",                              config_parse_net_condition,                               CONDITION_FIRMWARE,            offsetof(Network, conditions)},
      {(char*)0},
#line 313 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.Cost",                                 config_parse_uint32,                                      0,                             offsetof(Network, cost)},
      {(char*)0},
#line 120 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DNSOverTLS",                          config_parse_dns_over_tls_mode,                           0,                             offsetof(Network, dns_over_tls_mode)},
      {(char*)0}, {(char*)0},
#line 141 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.ConfigureWithoutCarrier",             config_parse_bool,                                        0,                             offsetof(Network, configure_without_carrier)},
#line 410 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.FirewallMark",                           config_parse_cake_fwmark,                                 QDISC_KIND_CAKE,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 396 "../git/src/network/networkd-network-gperf.gperf"
      {"BFIFO.Parent",                                config_parse_qdisc_parent,                                QDISC_KIND_BFIFO,              0},
      {(char*)0}, {(char*)0},
#line 240 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.IPServiceType",                        config_parse_dhcp_ip_service_type,                        0,                             offsetof(Network, dhcp_ip_service_type)},
#line 533 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.BlackList",                            config_parse_in_addr_prefixes,                            AF_INET,                       offsetof(Network, dhcp_deny_listed_ip)},
      {(char*)0}, {(char*)0},
#line 60 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Property",                              config_parse_match_property,                              0,                             offsetof(Network, match.property)},
#line 553 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.RouteTable",                             config_parse_dhcp_or_ra_route_table,                      AF_INET,                       0},
      {(char*)0},
#line 235 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.ListenPort",                           config_parse_uint16,                                      0,                             offsetof(Network, dhcp_client_port)},
      {(char*)0}, {(char*)0},
#line 558 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseDomainName",                        config_parse_dhcp_use_domains,                            AF_INET,                       0},
      {(char*)0},
#line 216 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseDomains",                           config_parse_dhcp_use_domains,                            AF_INET,                       0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 464 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.CEThresholdSec",  config_parse_fair_queueing_controlled_delay_usec,         QDISC_KIND_FQ_CODEL,           0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 571 "../git/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.Parent",                        config_parse_qdisc_parent,             _QDISC_KIND_INVALID,           0},
#line 200 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.MultiPathRoute",                        config_parse_multipath_route,                             0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 321 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.MulticastToUnicast",                   config_parse_tristate,                                    0,                             offsetof(Network, multicast_to_unicast)},
#line 285 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.MaxLeaseTimeSec",                  config_parse_sec,                                         0,                             offsetof(Network, dhcp_server_max_lease_time_usec)},
      {(char*)0}, {(char*)0},
#line 315 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.HairPin",                              config_parse_tristate,                                    0,                             offsetof(Network, hairpin)},
      {(char*)0},
#line 574 "../git/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorLossRate",       config_parse_network_emulator_rate,    0,                             0},
      {(char*)0},
#line 232 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RouteMetric",                          config_parse_dhcp_or_ra_route_metric,                     AF_INET,                       0},
#line 383 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.ListenOnly",                              config_parse_can_control_mode,                            CAN_CTRLMODE_LISTENONLY,       0},
      {(char*)0},
#line 575 "../git/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorDuplicateRate",  config_parse_network_emulator_rate,    0,                             0},
      {(char*)0}, {(char*)0},
#line 576 "../git/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorPacketLimit",    config_parse_network_emulator_packet_limit, 0,                        0},
#line 323 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.Learning",                             config_parse_tristate,                                    0,                             offsetof(Network, learning)},
      {(char*)0},
#line 180 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.Type",                      config_parse_routing_policy_rule_type,                    0,                             0},
      {(char*)0},
#line 351 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.DNS",                              config_parse_radv_dns,                                    0,                             0},
      {(char*)0}, {(char*)0},
#line 407 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.FlowIsolationMode",                      config_parse_cake_flow_isolation_mode,                    QDISC_KIND_CAKE,               0},
#line 224 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RequestBroadcast",                     config_parse_tristate,                                    0,                             offsetof(Network, dhcp_broadcast)},
      {(char*)0}, {(char*)0},
#line 58 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.BSSID",                                 config_parse_ether_addrs,                                 0,                             offsetof(Network, match.bssid)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 239 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.AllowList",                            config_parse_in_addr_prefixes,                            AF_INET,                       offsetof(Network, dhcp_allow_listed_ip)},
      {(char*)0},
#line 460 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.Flows",           config_parse_fair_queueing_controlled_delay_u32,          QDISC_KIND_FQ_CODEL,           0},
      {(char*)0}, {(char*)0},
#line 92 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.VRF",                                 config_parse_ifname,                                      0,                             offsetof(Network, vrf_name)},
#line 327 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.MulticastRouter",                      config_parse_multicast_router,                            0,                             offsetof(Network, multicast_router)},
#line 231 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.DUIDRawData",                          config_parse_network_duid_rawdata,                        0,                             0},
#line 188 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.MTUBytes",                              config_parse_route_mtu,                                   AF_UNSPEC,                     0},
      {(char*)0},
#line 572 "../git/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorDelaySec",       config_parse_network_emulator_delay,   0,                             0},
#line 282 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.RelayTarget",                      config_parse_in_addr_non_null,                            AF_INET,                       offsetof(Network, dhcp_server_relay_target)},
#line 199 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.TTLPropagate",                          config_parse_route_boolean,                               0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 573 "../git/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorDelayJitterSec", config_parse_network_emulator_delay,   0,                             0},
#line 353 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.Domains",                          config_parse_radv_search_domains,                         0,                             0},
#line 529 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.DNS",                    config_parse_radv_dns,                                    0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 228 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UserClass",                            config_parse_dhcp_user_or_vendor_class,                   AF_INET,                       offsetof(Network, dhcp_user_class)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 450 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.InitialQuantumBytes",            config_parse_fair_queueing_size,                          QDISC_KIND_FQ,                 0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 462 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.TargetSec",       config_parse_fair_queueing_controlled_delay_usec,         QDISC_KIND_FQ_CODEL,           0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 528 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.EmitDNS",                config_parse_bool,                                        0,                             offsetof(Network, router_emit_dns)},
#line 318 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.AllowPortToBeRoot",                    config_parse_tristate,                                    0,                             offsetof(Network, allow_port_to_be_root)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 392 "../git/src/network/networkd-network-gperf.gperf"
      {"IPoIB.Mode",                                  config_parse_ipoib_mode,                                  0,                             offsetof(Network, ipoib_mode)},
      {(char*)0},
#line 530 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.EmitDomains",            config_parse_bool,                                        0,                             offsetof(Network, router_emit_domains)},
      {(char*)0}, {(char*)0},
#line 559 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.CriticalConnection",                   config_parse_tristate,                                    0,                             offsetof(Network, dhcp_critical)},
#line 165 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.Priority",                  config_parse_routing_policy_rule_priority,                0,                             0},
      {(char*)0},
#line 208 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.ClientIdentifier",                     config_parse_dhcp_client_identifier,                      0,                             offsetof(Network, dhcp_client_identifier)},
#line 91 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.Bridge",                              config_parse_ifname,                                      0,                             offsetof(Network, bridge_name)},
#line 230 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.DUIDType",                             config_parse_network_duid_type,                           0,                             0},
#line 217 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseRoutes",                            config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_routes)},
      {(char*)0},
#line 149 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.Label",                               config_parse_label,                                       0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 280 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.ServerAddress",                    config_parse_dhcp_server_address,                         0,                             0},
#line 532 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.DNSLifetimeSec",         config_parse_sec,                                         0,                             offsetof(Network, router_dns_lifetime_usec)},
#line 220 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.Anonymize",                            config_parse_bool,                                        0,                             offsetof(Network, dhcp_anonymize)},
#line 492 "../git/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.Handle",                      config_parse_qdisc_handle,                                QDISC_KIND_NETEM,              0},
      {(char*)0}, {(char*)0},
#line 354 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.DNSLifetimeSec",                   config_parse_sec,                                         0,                             offsetof(Network, router_dns_lifetime_usec)},
      {(char*)0}, {(char*)0},
#line 211 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseNTP",                               config_parse_dhcp_use_ntp,                                AF_INET,                       0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 106 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.LinkLocalAddressing",                 config_parse_link_local_address_family,                   0,                             offsetof(Network, link_local)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 527 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.RouterPreference",       config_parse_router_preference,                           0,                             0},
      {(char*)0}, {(char*)0},
#line 113 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.Address",                             config_parse_address,                                     0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 311 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServerStaticLease.Address",               config_parse_dhcp_static_lease_address,                   0,                             0},
#line 55 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Kind",                                  config_parse_match_strv,                                  0,                             offsetof(Network, match.kind)},
#line 155 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.AutoJoin",                            config_parse_address_flags,                               IFA_F_MCAUTOJOIN,              0},
#line 356 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.Prefix",                           config_parse_prefix,                                      0,                             0},
#line 524 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.RouterLifetimeSec",      config_parse_sec,                                         0,                             offsetof(Network, router_lifetime_usec)},
#line 158 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.RouteMetric",                         config_parse_address_route_metric,                        0,                             0},
      {(char*)0},
#line 364 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6RoutePrefix.Route",                       config_parse_route_prefix,                                0,                             0},
#line 148 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.Broadcast",                           config_parse_broadcast,                                   0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 534 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.ClientIdentifier",                       config_parse_dhcp_client_identifier,                      0,                             offsetof(Network, dhcp_client_identifier)},
#line 349 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.RouterPreference",                 config_parse_router_preference,                           0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 260 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.IAID",                                 config_parse_iaid,                                        AF_INET6,                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 357 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.OnLink",                           config_parse_prefix_boolean,                              0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 330 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.Destination",                       config_parse_fdb_destination,                             0,                             0},
#line 101 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.VLAN",                                config_parse_stacked_netdev,                              NETDEV_KIND_VLAN,              offsetof(Network, stacked_netdev_names)},
#line 248 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseDNS",                               config_parse_dhcp_use_dns,                                AF_INET6,                      0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 147 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.Peer",                                config_parse_address,                                     0,                             0},
#line 234 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseTimezone",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_timezone)},
      {(char*)0}, {(char*)0},
#line 164 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.TypeOfService",             config_parse_routing_policy_rule_tos,                     0,                             0},
      {(char*)0}, {(char*)0},
#line 140 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.BindCarrier",                         config_parse_strv,                                        0,                             offsetof(Network, bind_carrier)},
#line 555 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.ListenPort",                             config_parse_uint16,                                      0,                             offsetof(Network, dhcp_client_port)},
      {(char*)0},
#line 365 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6RoutePrefix.LifetimeSec",                 config_parse_route_prefix_lifetime,                       0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 414 "../git/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.Handle",                      config_parse_qdisc_handle,                                QDISC_KIND_CODEL,              0},
#line 310 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.BootFilename",                     config_parse_string,                                      CONFIG_PARSE_STRING_SAFE_AND_ASCII, offsetof(Network, dhcp_server_boot_filename)},
#line 190 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.GatewayOnlink",                         config_parse_route_boolean,                               0,                             0},
#line 324 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.ProxyARP",                             config_parse_tristate,                                    0,                             offsetof(Network, bridge_proxy_arp)},
      {(char*)0},
#line 432 "../git/src/network/networkd-network-gperf.gperf"
      {"PFIFO.Handle",                                config_parse_qdisc_handle,                                QDISC_KIND_PFIFO,              0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 307 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.BindToInterface",                  config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_bind_to_interface)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 402 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.AutoRateIngress",                        config_parse_cake_tristate,                               QDISC_KIND_CAKE,               0},
      {(char*)0}, {(char*)0},
#line 65 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Architecture",                          config_parse_net_condition,                               CONDITION_ARCHITECTURE,        offsetof(Network, conditions)},
      {(char*)0},
#line 500 "../git/src/network/networkd-network-gperf.gperf"
      {"PIE.PacketLimit",                             config_parse_pie_packet_limit,                            QDISC_KIND_PIE,                0},
      {(char*)0},
#line 250 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseDomains",                           config_parse_dhcp_use_domains,                            AF_INET6,                      0},
      {(char*)0},
#line 176 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.Family",                    config_parse_routing_policy_rule_family,                  0,                             0},
#line 51 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.PermanentMACAddress",                   config_parse_hw_addrs,                                    0,                             offsetof(Network, match.permanent_hw_addr)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 426 "../git/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.Handle",        config_parse_qdisc_handle,                                QDISC_KIND_ETS,                0},
#line 348 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.OtherInformation",                 config_parse_bool,                                        0,                             offsetof(Network, router_other_information)},
      {(char*)0}, {(char*)0},
#line 427 "../git/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.Bands",         config_parse_ets_u8,                                      QDISC_KIND_ETS,                0},
#line 425 "../git/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.Parent",        config_parse_qdisc_parent,                                QDISC_KIND_ETS,                0},
      {(char*)0}, {(char*)0},
#line 388 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.PresumeACK",                              config_parse_can_control_mode,                            CAN_CTRLMODE_PRESUME_ACK,      0},
#line 247 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseDelegatedPrefix",                   config_parse_bool,                                        0,                             offsetof(Network, dhcp6_use_pd_prefix)},
#line 428 "../git/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.StrictBands",   config_parse_ets_u8,                                      QDISC_KIND_ETS,                0},
#line 429 "../git/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.QuantumBytes",  config_parse_ets_quanta,                                  QDISC_KIND_ETS,                0},
      {(char*)0}, {(char*)0},
#line 243 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RouteMTUBytes",                        config_parse_mtu,                                         AF_INET,                       offsetof(Network, dhcp_route_mtu)},
#line 400 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.Handle",                                 config_parse_qdisc_handle,                                QDISC_KIND_CAKE,               0},
#line 312 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServerStaticLease.MACAddress",            config_parse_dhcp_static_lease_hwaddr,                    0,                             0},
#line 560 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.RouteMetric",                          config_parse_dhcp_or_ra_route_metric,                     AF_INET6,                      0},
      {(char*)0},
#line 326 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.Priority",                             config_parse_bridge_port_priority,                        0,                             offsetof(Network, priority)},
#line 363 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.Token",                            config_parse_prefix_token,                                0,                             0},
#line 394 "../git/src/network/networkd-network-gperf.gperf"
      {"QDisc.Parent",                                config_parse_qdisc_parent,                                _QDISC_KIND_INVALID,           0},
#line 287 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitDNS",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_DNS].emit)},
      {(char*)0},
#line 191 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.IPv6Preference",                        config_parse_ipv6_route_preference,                       0,                             0},
#line 73 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.Promiscuous",                            config_parse_tristate,                                    0,                             offsetof(Network, promiscuous)},
      {(char*)0},
#line 291 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitSIP",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_SIP].emit)},
#line 295 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitSMTP",                         config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_SMTP].emit)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 153 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.PrefixRoute",                         config_parse_address_flags,                               IFA_F_NOPREFIXROUTE,           0 /* deprecated */},
#line 61 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Host",                                  config_parse_net_condition,                               CONDITION_HOST,                offsetof(Network, conditions)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 71 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.Multicast",                              config_parse_tristate,                                    0,                             offsetof(Network, multicast)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 289 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitNTP",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_NTP].emit)},
#line 463 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.IntervalSec",     config_parse_fair_queueing_controlled_delay_usec,         QDISC_KIND_FQ_CODEL,           0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 262 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.DUIDRawData",                          config_parse_duid_rawdata,                                0,                             offsetof(Network, dhcp6_duid)},
      {(char*)0},
#line 437 "../git/src/network/networkd-network-gperf.gperf"
      {"PFIFOHeadDrop.Handle",                        config_parse_qdisc_handle,                                QDISC_KIND_PFIFO_HEAD_DROP,    0},
#line 562 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.ForceDHCPv6PDOtherInformation",        config_parse_warn_compat,                                 DISABLED_LEGACY,               0},
#line 362 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.RouteMetric",                      config_parse_prefix_metric,                               0,                             0},
#line 403 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.OverheadBytes",                          config_parse_cake_overhead,                               QDISC_KIND_CAKE,               0},
#line 325 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.ProxyARPWiFi",                         config_parse_tristate,                                    0,                             offsetof(Network, bridge_proxy_arp_wifi)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 293 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitPOP3",                         config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_POP3].emit)},
#line 436 "../git/src/network/networkd-network-gperf.gperf"
      {"PFIFOHeadDrop.Parent",                        config_parse_qdisc_parent,                                QDISC_KIND_PFIFO_HEAD_DROP,    0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 254 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UserClass",                            config_parse_dhcp_user_or_vendor_class,                   AF_INET6,                      offsetof(Network, dhcp6_user_class)},
      {(char*)0},
#line 213 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseSIP",                               config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_sip)},
      {(char*)0}, {(char*)0},
#line 405 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.CompensationMode",                       config_parse_cake_compensation_mode,                      QDISC_KIND_CAKE,               0},
#line 509 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.Rate",                      config_parse_token_bucket_filter_rate,                    QDISC_KIND_TBF,                0},
      {(char*)0},
#line 508 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.Handle",                    config_parse_qdisc_handle,                                QDISC_KIND_TBF,                0},
      {(char*)0},
#line 514 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.PeakRate",                  config_parse_token_bucket_filter_rate,                    QDISC_KIND_TBF,                0},
      {(char*)0}, {(char*)0},
#line 163 "../git/src/network/networkd-network-gperf.gperf"
      {"Neighbor.MACAddress",                         config_parse_neighbor_lladdr,                             0,                             0 /* deprecated */},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 105 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.DHCPServer",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_server)},
#line 507 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.Parent",                    config_parse_qdisc_parent,                                QDISC_KIND_TBF,                0},
#line 438 "../git/src/network/networkd-network-gperf.gperf"
      {"PFIFOHeadDrop.PacketLimit",                   config_parse_pfifo_size,                                  QDISC_KIND_PFIFO_HEAD_DROP,    0},
      {(char*)0}, {(char*)0},
#line 581 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.Burst",                     config_parse_token_bucket_filter_size,                    QDISC_KIND_TBF,                0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 566 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.ManageTemporaryAddress", config_parse_bool,                                      0,                             offsetof(Network, dhcp_pd_manage_temporary_address)},
#line 513 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.MPUBytes",                  config_parse_token_bucket_filter_size,                    QDISC_KIND_TBF,                0},
#line 582 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.LimitSize",                 config_parse_token_bucket_filter_size,                    QDISC_KIND_TBF,                0},
      {(char*)0}, {(char*)0},
#line 261 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.DUIDType",                             config_parse_duid_type,                                   0,                             offsetof(Network, dhcp6_duid)},
      {(char*)0},
#line 478 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucket.Handle",                 config_parse_qdisc_handle,                                QDISC_KIND_HTB,                0},
#line 237 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendDecline",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_send_decline)},
#line 298 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.LPR",                              config_parse_dhcp_server_emit,                            0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_LPR])},
#line 316 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.Isolated",                             config_parse_tristate,                                    0,                             offsetof(Network, isolated)},
      {(char*)0}, {(char*)0},
#line 408 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.NAT",                                    config_parse_cake_tristate,                               QDISC_KIND_CAKE,               0},
      {(char*)0},
#line 162 "../git/src/network/networkd-network-gperf.gperf"
      {"Neighbor.LinkLayerAddress",                   config_parse_neighbor_lladdr,                             0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 487 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.Rate",              config_parse_hierarchy_token_bucket_class_rate,           TCLASS_KIND_HTB,               0},
#line 435 "../git/src/network/networkd-network-gperf.gperf"
      {"PFIFOFast.Handle",                            config_parse_qdisc_handle,                                QDISC_KIND_PFIFO_FAST,         0},
      {(char*)0},
#line 251 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseNTP",                               config_parse_dhcp_use_ntp,                                AF_INET6,                      0},
      {(char*)0},
#line 502 "../git/src/network/networkd-network-gperf.gperf"
      {"StochasticFairBlue.Handle",                   config_parse_qdisc_handle,                                QDISC_KIND_SFB,                0},
      {(char*)0},
#line 333 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.OutgoingInterface",                 config_parse_fdb_interface,                               0,                             0},
#line 484 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.QuantumBytes",      config_parse_hierarchy_token_bucket_class_size,           TCLASS_KIND_HTB,               0},
#line 486 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.OverheadBytes",     config_parse_hierarchy_token_bucket_class_size,           TCLASS_KIND_HTB,               0},
      {(char*)0}, {(char*)0},
#line 124 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPForward",                           config_parse_address_family_with_kernel,                  0,                             offsetof(Network, ip_forward)},
      {(char*)0},
#line 194 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.InitialCongestionWindow",               config_parse_tcp_window,                                  0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 488 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.CeilRate",          config_parse_hierarchy_token_bucket_class_rate,           TCLASS_KIND_HTB,               0},
      {(char*)0},
#line 85 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.LinkState",                            config_parse_sr_iov_link_state,                           0,                             offsetof(Network, sr_iov_by_section)},
      {(char*)0},
#line 181 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.Gateway",                               config_parse_gateway,                                     0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 84 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.Trust",                                config_parse_sr_iov_boolean,                              0,                             offsetof(Network, sr_iov_by_section)},
      {(char*)0},
#line 319 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.UnicastFlood",                         config_parse_tristate,                                    0,                             offsetof(Network, unicast_flood)},
      {(char*)0},
#line 490 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.CeilBufferBytes",   config_parse_hierarchy_token_bucket_class_size,           TCLASS_KIND_HTB,               0},
#line 76 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.RequiredForOnline",                      config_parse_required_for_online,                         0,                             0},
#line 515 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.LatencySec",                config_parse_token_bucket_filter_latency,                 QDISC_KIND_TBF,                0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 477 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucket.Parent",                 config_parse_qdisc_parent,                                QDISC_KIND_HTB,                0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 457 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.Handle",          config_parse_qdisc_handle,                                QDISC_KIND_FQ_CODEL,           0},
      {(char*)0}, {(char*)0},
#line 481 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.Parent",            config_parse_tclass_parent,                               TCLASS_KIND_HTB,               0},
#line 68 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.MTUBytes",                               config_parse_mtu,                                         AF_UNSPEC,                     offsetof(Network, mtu)},
#line 440 "../git/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueing.Handle",                    config_parse_qdisc_handle,                                QDISC_KIND_QFQ,                0},
      {(char*)0}, {(char*)0},
#line 517 "../git/src/network/networkd-network-gperf.gperf"
      {"TrivialLinkEqualizer.Handle",                 config_parse_qdisc_handle,                                QDISC_KIND_TEQL,               0},
#line 567 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.Token",                config_parse_address_generation_type,                     0,                             offsetof(Network, dhcp_pd_tokens)},
#line 447 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.PacketLimit",                    config_parse_fair_queueing_u32,                           QDISC_KIND_FQ,                 0},
      {(char*)0},
#line 465 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.ECN",             config_parse_fair_queueing_controlled_delay_bool,         QDISC_KIND_FQ_CODEL,           0},
      {(char*)0},
#line 308 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.BootServerAddress",                config_parse_in_addr_non_null,                            AF_INET,                       offsetof(Network, dhcp_server_boot_server_address)},
#line 439 "../git/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueing.Parent",                    config_parse_qdisc_parent,                                QDISC_KIND_QFQ,                0},
#line 52 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Path",                                  config_parse_match_strv,                                  0,                             offsetof(Network, match.path)},
#line 299 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitRouter",                       config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_emit_router)},
      {(char*)0},
#line 93 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPoIB",                               config_parse_stacked_netdev,                              NETDEV_KIND_IPOIB,             offsetof(Network, stacked_netdev_names)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 78 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.VirtualFunction",                      config_parse_sr_iov_uint32,                               0,                             offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 206 "../git/src/network/networkd-network-gperf.gperf"
      {"NextHop.Blackhole",                           config_parse_nexthop_blackhole,                           0,                             0},
#line 236 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendRelease",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_send_release)},
#line 441 "../git/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueingClass.Parent",               config_parse_tclass_parent,                               TCLASS_KIND_QFQ,               0},
      {(char*)0},
#line 320 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.MulticastFlood",                       config_parse_tristate,                                    0,                             offsetof(Network, multicast_flood)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 543 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.SendHostname",                           config_parse_bool,                                        0,                             offsetof(Network, dhcp_send_hostname)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 88 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.KeepMaster",                          config_parse_bool,                                        0,                             offsetof(Network, keep_master)},
#line 549 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.IAID",                                   config_parse_iaid,                                        AF_INET,                       0},
#line 115 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.Domains",                             config_parse_domains,                                     0,                             0},
      {(char*)0},
#line 241 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendOption",                           config_parse_dhcp_send_option,                            AF_INET,                       offsetof(Network, dhcp_client_send_options)},
#line 525 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.Managed",                config_parse_bool,                                        0,                             offsetof(Network, router_managed)},
#line 81 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.VLANProtocol",                         config_parse_sr_iov_vlan_proto,                           0,                             offsetof(Network, sr_iov_by_section)},
#line 461 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.QuantumBytes",    config_parse_fair_queueing_controlled_delay_size,         QDISC_KIND_FQ_CODEL,           0},
      {(char*)0},
#line 455 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.CEThresholdSec",                 config_parse_fair_queueing_usec,                          QDISC_KIND_FQ,                 0},
#line 301 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitTimezone",                     config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_emit_timezone)},
      {(char*)0},
#line 62 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.Virtualization",                        config_parse_net_condition,                               CONDITION_VIRTUALIZATION,      offsetof(Network, conditions)},
      {(char*)0},
#line 516 "../git/src/network/networkd-network-gperf.gperf"
      {"TrivialLinkEqualizer.Parent",                 config_parse_qdisc_parent,                                QDISC_KIND_TEQL,               0},
      {(char*)0},
#line 411 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.Wash",                                   config_parse_cake_tristate,                               QDISC_KIND_CAKE,               0},
      {(char*)0}, {(char*)0},
#line 90 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.Bond",                                config_parse_ifname,                                      0,                             offsetof(Network, bond_name)},
      {(char*)0},
#line 568 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.RouteMetric",          config_parse_uint32,                                      0,                             offsetof(Network, dhcp_pd_route_metric)},
#line 136 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.PrimarySlave",                        config_parse_bool,                                        0,                             offsetof(Network, primary_slave)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 317 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.FastLeave",                            config_parse_tristate,                                    0,                             offsetof(Network, fast_leave)},
#line 218 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseGateway",                           config_parse_tristate,                                    0,                             offsetof(Network, dhcp_use_gateway)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 489 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.BufferBytes",       config_parse_hierarchy_token_bucket_class_size,           TCLASS_KIND_HTB,               0},
#line 56 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.WLANInterfaceType",                     config_parse_match_strv,                                  0,                             offsetof(Network, match.wlan_iftype)},
      {(char*)0}, {(char*)0},
#line 377 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.DataPropagationSegment",                  config_parse_uint32,                                      0,                             offsetof(Network, can_data_propagation_segment)},
#line 397 "../git/src/network/networkd-network-gperf.gperf"
      {"BFIFO.Handle",                                config_parse_qdisc_handle,                                QDISC_KIND_BFIFO,              0},
      {(char*)0},
#line 109 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4LLRoute",                         config_parse_bool,                                        0,                             offsetof(Network, ipv4ll_route)},
#line 134 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4RouteLocalnet",                   config_parse_tristate,                                    0,                             offsetof(Network, ipv4_route_localnet)},
      {(char*)0},
#line 305 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.SendVendorOption",                 config_parse_dhcp_send_option,                            0,                             offsetof(Network, dhcp_server_send_vendor_options)},
#line 133 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4AcceptLocal",                     config_parse_tristate,                                    0,                             offsetof(Network, ipv4_accept_local)},
#line 443 "../git/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueingClass.Weight",               config_parse_quick_fair_queueing_weight,                  TCLASS_KIND_QFQ,               0},
#line 137 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4ProxyARP",                        config_parse_tristate,                                    0,                             offsetof(Network, proxy_arp)},
#line 512 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.MTUBytes",                  config_parse_token_bucket_filter_size,                    QDISC_KIND_TBF,                0},
      {(char*)0}, {(char*)0},
#line 340 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.SubnetId",               config_parse_dhcp_pd_subnet_id,                           0,                             offsetof(Network, dhcp_pd_subnet_id)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 99 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.MACVTAP",                             config_parse_stacked_netdev,                              NETDEV_KIND_MACVTAP,           offsetof(Network, stacked_netdev_names)},
#line 161 "../git/src/network/networkd-network-gperf.gperf"
      {"Neighbor.Address",                            config_parse_neighbor_address,                            0,                             0},
#line 376 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.DataTimeQuantaNSec",                      config_parse_can_time_quanta,                             0,                             offsetof(Network, can_data_time_quanta_ns)},
#line 347 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.Managed",                          config_parse_bool,                                        0,                             offsetof(Network, router_managed)},
      {(char*)0},
#line 98 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.MACVLAN",                             config_parse_stacked_netdev,                              NETDEV_KIND_MACVLAN,           offsetof(Network, stacked_netdev_names)},
#line 535 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseDNS",                                 config_parse_dhcp_use_dns,                                AF_UNSPEC,                     0},
      {(char*)0},
#line 215 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseHostname",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_hostname)},
      {(char*)0}, {(char*)0},
#line 244 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.FallbackLeaseLifetimeSec",             config_parse_dhcp_fallback_lease_lifetime,                0,                             0},
#line 154 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.AddPrefixRoute",                      config_parse_address_flags,                               IFA_F_NOPREFIXROUTE,           0},
#line 369 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.TimeQuantaNSec",                          config_parse_can_time_quanta,                             0,                             offsetof(Network, can_time_quanta_ns)},
#line 548 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UserClass",                              config_parse_dhcp_user_or_vendor_class,                   AF_INET,                       offsetof(Network, dhcp_user_class)},
#line 146 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.Address",                             config_parse_address,                                     0,                             0},
#line 360 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.PreferredLifetimeSec",             config_parse_prefix_lifetime,                             0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 368 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.SamplePoint",                             config_parse_permille,                                    0,                             offsetof(Network, can_sample_point)},
#line 538 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseHostname",                            config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_hostname)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 536 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseNTP",                                 config_parse_dhcp_use_ntp,                                AF_UNSPEC,                     0},
#line 444 "../git/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueingClass.MaxPacketBytes",       config_parse_quick_fair_queueing_max_packet,              TCLASS_KIND_QFQ,               0},
#line 245 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.Use6RD",                               config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_6rd)},
#line 541 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseRoutes",                              config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_routes)},
      {(char*)0}, {(char*)0},
#line 361 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.Assign",                           config_parse_prefix_boolean,                              0,                             0},
#line 179 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.SuppressPrefixLength",      config_parse_routing_policy_rule_suppress_prefixlen,      0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 372 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.PhaseBufferSegment2",                     config_parse_uint32,                                      0,                             offsetof(Network, can_phase_buffer_segment_2)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 479 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucket.DefaultClass",           config_parse_hierarchy_token_bucket_default_class,        QDISC_KIND_HTB,                0},
      {(char*)0},
#line 178 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.SuppressInterfaceGroup",    config_parse_routing_policy_rule_suppress_ifgroup,        0,                             0},
#line 393 "../git/src/network/networkd-network-gperf.gperf"
      {"IPoIB.IgnoreUserspaceMulticastGroups",        config_parse_tristate,                                    0,                             offsetof(Network, ipoib_umcast)},
      {(char*)0}, {(char*)0},
#line 483 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.Priority",          config_parse_hierarchy_token_bucket_class_u32,            TCLASS_KIND_HTB,               0},
      {(char*)0},
#line 547 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.VendorClassIdentifier",                  config_parse_string,                                      CONFIG_PARSE_STRING_SAFE,      offsetof(Network, dhcp_vendor_class_identifier)},
      {(char*)0},
#line 350 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.EmitDNS",                          config_parse_bool,                                        0,                             offsetof(Network, router_emit_dns)},
      {(char*)0}, {(char*)0},
#line 551 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.DUIDRawData",                            config_parse_network_duid_rawdata,                        0,                             0},
      {(char*)0},
#line 371 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.PhaseBufferSegment1",                     config_parse_uint32,                                      0,                             offsetof(Network, can_phase_buffer_segment_1)},
#line 469 "../git/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.Parent",          config_parse_qdisc_parent,                                QDISC_KIND_GRED,               0},
      {(char*)0}, {(char*)0},
#line 472 "../git/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.DefaultVirtualQueue", config_parse_generic_random_early_detection_u32,      QDISC_KIND_GRED,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 203 "../git/src/network/networkd-network-gperf.gperf"
      {"NextHop.Gateway",                             config_parse_nexthop_gateway,                             0,                             0},
#line 50 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.MACAddress",                            config_parse_hw_addrs,                                    0,                             offsetof(Network, match.hw_addr)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 95 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPVTAP",                              config_parse_stacked_netdev,                              NETDEV_KIND_IPVTAP,            offsetof(Network, stacked_netdev_names)},
#line 449 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.QuantumBytes",                   config_parse_fair_queueing_size,                          QDISC_KIND_FQ,                 0},
      {(char*)0},
#line 352 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.EmitDomains",                      config_parse_bool,                                        0,                             offsetof(Network, router_emit_domains)},
#line 255 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.VendorClass",                          config_parse_dhcp_user_or_vendor_class,                   AF_INET6,                      offsetof(Network, dhcp6_vendor_class)},
      {(char*)0},
#line 152 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.ManageTemporaryAddress",              config_parse_address_flags,                               IFA_F_MANAGETEMPADDR,          0},
#line 281 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.UplinkInterface",                  config_parse_uplink,                                      0,                             0},
#line 72 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.AllMulticast",                           config_parse_tristate,                                    0,                             offsetof(Network, allmulticast)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 358 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.AddressAutoconfiguration",         config_parse_prefix_boolean,                              0,                             0},
      {(char*)0},
#line 578 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.InitialQuantum",                 config_parse_fair_queueing_size,                          QDISC_KIND_FQ,                 0},
#line 453 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.OrphanMask",                     config_parse_fair_queueing_u32,                           QDISC_KIND_FQ,                 0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 143 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.KeepConfiguration",                   config_parse_keep_configuration,                          0,                             offsetof(Network, keep_configuration)},
#line 563 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.SubnetId",             config_parse_dhcp_pd_subnet_id,                           0,                             offsetof(Network, dhcp_pd_subnet_id)},
#line 168 "../git/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.From",                      config_parse_routing_policy_rule_prefix,                  0,                             0},
#line 510 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.BurstBytes",                config_parse_token_bucket_filter_size,                    QDISC_KIND_TBF,                0},
#line 451 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.MaximumRate",                    config_parse_fair_queueing_max_rate,                      QDISC_KIND_FQ,                 0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 238 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.DenyList",                             config_parse_in_addr_prefixes,                            AF_INET,                       offsetof(Network, dhcp_deny_listed_ip)},
#line 219 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RequestOptions",                       config_parse_dhcp_request_options,                        AF_INET,                       0},
      {(char*)0},
#line 511 "../git/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.LimitBytes",                config_parse_token_bucket_filter_size,                    QDISC_KIND_TBF,                0},
#line 267 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseDNS",                         config_parse_bool,                                        0,                             offsetof(Network, ipv6_accept_ra_use_dns)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 279 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.Token",                          config_parse_address_generation_type,                     0,                             offsetof(Network, ndisc_tokens)},
      {(char*)0},
#line 83 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.QueryReceiveSideScaling",              config_parse_sr_iov_boolean,                              0,                             offsetof(Network, sr_iov_by_section)},
      {(char*)0},
#line 448 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.FlowLimit",                      config_parse_fair_queueing_u32,                           QDISC_KIND_FQ,                 0},
#line 268 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseDomains",                     config_parse_ipv6_accept_ra_use_domains,                  0,                             offsetof(Network, ipv6_accept_ra_use_domains)},
      {(char*)0}, {(char*)0},
#line 569 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.DenyList",                       config_parse_in_addr_prefixes,                            AF_INET6,                      offsetof(Network, ndisc_deny_listed_prefix)},
      {(char*)0},
#line 271 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouteTable",                     config_parse_dhcp_or_ra_route_table,                      AF_INET6,                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 521 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6Token",                           config_parse_address_generation_type,                     0,                             offsetof(Network, ndisc_tokens)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 570 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.BlackList",                      config_parse_in_addr_prefixes,                            AF_INET6,                      offsetof(Network, ndisc_deny_listed_prefix)},
#line 102 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.VXLAN",                               config_parse_stacked_netdev,                              NETDEV_KIND_VXLAN,             offsetof(Network, stacked_netdev_names)},
      {(char*)0},
#line 390 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.ClassicDataLengthCode",                   config_parse_can_control_mode,                            CAN_CTRLMODE_CC_LEN8_DLC,      0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 565 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.Assign",               config_parse_bool,                                        0,                             offsetof(Network, dhcp_pd_assign)},
      {(char*)0},
#line 564 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.Announce",             config_parse_bool,                                        0,                             offsetof(Network, dhcp_pd_announce)},
#line 259 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.SendOption",                           config_parse_dhcp_send_option,                            AF_INET6,                      offsetof(Network, dhcp6_client_send_options)},
      {(char*)0}, {(char*)0},
#line 336 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeVLAN.PVID",                             config_parse_brvlan_pvid,                                 0,                             0},
#line 278 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouteDenyList",                  config_parse_in_addr_prefixes,                            AF_INET6,                      offsetof(Network, ndisc_deny_listed_route_prefix)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 264 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseRoutePrefix",                 config_parse_bool,                                        0,                             offsetof(Network, ipv6_accept_ra_use_route_prefix)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 406 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.UseRawPacketSize",                       config_parse_cake_tristate,                               QDISC_KIND_CAKE,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 70 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.ARP",                                    config_parse_tristate,                                    0,                             offsetof(Network, arp)},
#line 189 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.GatewayOnLink",                         config_parse_route_boolean,                               0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 108 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6StableSecretAddress",             config_parse_in_addr_non_null,                            AF_INET6,                      offsetof(Network, ipv6ll_stable_secret)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 467 "../git/src/network/networkd-network-gperf.gperf"
      {"FlowQueuePIE.Handle",                         config_parse_qdisc_handle,                                QDISC_KIND_FQ_PIE,             0},
#line 131 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6ProxyNDP",                        config_parse_tristate,                                    0,                             offsetof(Network, ipv6_proxy_ndp)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 272 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouteMetric",                    config_parse_dhcp_or_ra_route_metric,                     AF_INET6,                      0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 482 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.ClassId",           config_parse_tclass_classid,                              TCLASS_KIND_HTB,               0},
      {(char*)0}, {(char*)0},
#line 322 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.NeighborSuppression",                  config_parse_tristate,                                    0,                             offsetof(Network, neighbor_suppression)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 249 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseHostname",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp6_use_hostname)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 266 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseOnLinkPrefix",                config_parse_bool,                                        0,                             offsetof(Network, ipv6_accept_ra_use_onlink_prefix)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 309 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.BootServerName",                   config_parse_dns_name,                                    0,                             offsetof(Network, dhcp_server_boot_server_name)},
      {(char*)0},
#line 395 "../git/src/network/networkd-network-gperf.gperf"
      {"QDisc.Handle",                                config_parse_qdisc_handle,                                _QDISC_KIND_INVALID,           0},
#line 421 "../git/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinScheduler.Handle",           config_parse_qdisc_handle,                                QDISC_KIND_DRR,                0},
      {(char*)0},
#line 202 "../git/src/network/networkd-network-gperf.gperf"
      {"NextHop.Id",                                  config_parse_nexthop_id,                                  0,                             0},
      {(char*)0}, {(char*)0},
#line 420 "../git/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinScheduler.Parent",           config_parse_qdisc_parent,                                QDISC_KIND_DRR,                0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 139 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6ProxyNDPAddress",                 config_parse_ipv6_proxy_ndp_address,                      0,                             0},
#line 422 "../git/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinSchedulerClass.Parent",      config_parse_tclass_parent,                               TCLASS_KIND_DRR,               0},
#line 466 "../git/src/network/networkd-network-gperf.gperf"
      {"FlowQueuePIE.Parent",                         config_parse_qdisc_parent,                                QDISC_KIND_FQ_PIE,             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 424 "../git/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinSchedulerClass.QuantumBytes", config_parse_drr_size,                                   TCLASS_KIND_DRR,               0},
      {(char*)0},
#line 398 "../git/src/network/networkd-network-gperf.gperf"
      {"BFIFO.LimitBytes",                            config_parse_bfifo_size,                                  QDISC_KIND_BFIFO,              0},
      {(char*)0},
#line 518 "../git/src/network/networkd-network-gperf.gperf"
      {"TrivialLinkEqualizer.Id",                     config_parse_trivial_link_equalizer_id,                   QDISC_KIND_TEQL,               0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 198 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.FastOpenNoCookie",                      config_parse_route_boolean,                               0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 265 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseAutonomousPrefix",            config_parse_bool,                                        0,                             offsetof(Network, ipv6_accept_ra_use_autonomous_prefix)},
#line 522 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6PrefixDelegation",                config_parse_router_prefix_delegation,                    0,                             offsetof(Network, router_prefix_delegation)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 197 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.QuickAck",                              config_parse_route_boolean,                               0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 531 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.Domains",                config_parse_radv_search_domains,                         0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 270 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.DHCPv6Client",                   config_parse_ipv6_accept_ra_start_dhcp6_client,           0,                             offsetof(Network, ipv6_accept_ra_start_dhcp6_client)},
      {(char*)0}, {(char*)0},
#line 157 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.Scope",                               config_parse_address_scope,                               0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 225 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.VendorClassIdentifier",                config_parse_string,                                      CONFIG_PARSE_STRING_SAFE,      offsetof(Network, dhcp_vendor_class_identifier)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 263 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseGateway",                     config_parse_bool,                                        0,                             offsetof(Network, ipv6_accept_ra_use_gateway)},
      {(char*)0},
#line 283 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.RelayAgentCircuitId",              config_parse_dhcp_server_relay_agent_suboption,           0,                             offsetof(Network, dhcp_server_relay_agent_circuit_id)},
      {(char*)0}, {(char*)0},
#line 128 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6AcceptRouterAdvertisements",      config_parse_tristate,                                    0,                             offsetof(Network, ipv6_accept_ra)},
#line 542 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.Anonymize",                              config_parse_bool,                                        0,                             offsetof(Network, dhcp_anonymize)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 412 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.SplitGSO",                               config_parse_cake_tristate,                               QDISC_KIND_CAKE,               0},
#line 221 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendHostname",                         config_parse_bool,                                        0,                             offsetof(Network, dhcp_send_hostname)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 257 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.PrefixDelegationHint",                 config_parse_dhcp6_pd_prefix_hint,                        0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 253 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.RequestOptions",                       config_parse_dhcp_request_options,                        AF_INET6,                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 75 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.ActivationPolicy",                       config_parse_activation_policy,                           0,                             offsetof(Network, activation_policy)},
#line 526 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.OtherInformation",       config_parse_bool,                                        0,                             offsetof(Network, router_other_information)},
#line 297 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitLPR",                          config_parse_bool,                                        0,                             offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_LPR].emit)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 151 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.HomeAddress",                         config_parse_address_flags,                               IFA_F_HOMEADDRESS,             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 355 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.UplinkInterface",                  config_parse_uplink,                                      0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 430 "../git/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.PriorityMap",   config_parse_ets_prio,                                    QDISC_KIND_ETS,                0},
      {(char*)0}, {(char*)0},
#line 205 "../git/src/network/networkd-network-gperf.gperf"
      {"NextHop.OnLink",                              config_parse_nexthop_onlink,                              0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 94 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPVLAN",                              config_parse_stacked_netdev,                              NETDEV_KIND_IPVLAN,            offsetof(Network, stacked_netdev_names)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 520 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4LL",                              config_parse_ipv4ll,                                      0,                             offsetof(Network, link_local)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 475 "../git/src/network/networkd-network-gperf.gperf"
      {"HeavyHitterFilter.Handle",                    config_parse_qdisc_handle,                                QDISC_KIND_HHF,                0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 544 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.Hostname",                               config_parse_hostname,                                    0,                             offsetof(Network, dhcp_hostname)},
#line 474 "../git/src/network/networkd-network-gperf.gperf"
      {"HeavyHitterFilter.Parent",                    config_parse_qdisc_parent,                                QDISC_KIND_HHF,                0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 476 "../git/src/network/networkd-network-gperf.gperf"
      {"HeavyHitterFilter.PacketLimit",               config_parse_heavy_hitter_filter_packet_limit,            QDISC_KIND_HHF,                0},
#line 132 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6MTUBytes",                        config_parse_mtu,                                         AF_INET6,                      offsetof(Network, ipv6_mtu)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 80 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.QualityOfService",                     config_parse_sr_iov_uint32,                               0,                             offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 246 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseAddress",                           config_parse_bool,                                        0,                             offsetof(Network, dhcp6_use_address)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 473 "../git/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.GenericRIO",      config_parse_generic_random_early_detection_bool,         QDISC_KIND_GRED,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 328 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.MACAddress",                        config_parse_fdb_hwaddr,                                  0,                             0},
      {(char*)0}, {(char*)0},
#line 63 "../git/src/network/networkd-network-gperf.gperf"
      {"Match.KernelCommandLine",                     config_parse_net_condition,                               CONDITION_KERNEL_COMMAND_LINE, offsetof(Network, conditions)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 214 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseMTU",                               config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_mtu)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 346 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.RouterLifetimeSec",                config_parse_router_lifetime,                             0,                             offsetof(Network, router_lifetime_usec)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 201 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.NextHop",                               config_parse_route_nexthop,                               0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 227 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.MaxAttempts",                          config_parse_dhcp_max_attempts,                           0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 129 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6DuplicateAddressDetection",       config_parse_int,                                         0,                             offsetof(Network, ipv6_dad_transmits)},
      {(char*)0}, {(char*)0},
#line 150 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.PreferredLifetime",                   config_parse_lifetime,                                    0,                             0},
      {(char*)0}, {(char*)0},
#line 242 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendVendorOption",                     config_parse_dhcp_send_option,                            0,                             offsetof(Network, dhcp_client_send_vendor_options)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 470 "../git/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.Handle",          config_parse_qdisc_handle,                                QDISC_KIND_GRED,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 401 "../git/src/network/networkd-network-gperf.gperf"
      {"CAKE.Bandwidth",                              config_parse_cake_bandwidth,                              QDISC_KIND_CAKE,               0},
#line 67 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.MACAddress",                             config_parse_hw_addr,                                     0,                             offsetof(Network, hw_addr)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 480 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucket.RateToQuantum",          config_parse_hierarchy_token_bucket_u32,                  QDISC_KIND_HTB,                0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 79 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.VLANId",                               config_parse_sr_iov_uint32,                               0,                             offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0},
#line 380 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.DataSyncJumpWidth",                       config_parse_uint32,                                      0,                             offsetof(Network, can_data_sync_jump_width)},
      {(char*)0},
#line 207 "../git/src/network/networkd-network-gperf.gperf"
      {"NextHop.Group",                               config_parse_nexthop_group,                               0,                             0},
#line 314 "../git/src/network/networkd-network-gperf.gperf"
      {"Bridge.UseBPDU",                              config_parse_tristate,                                    0,                             offsetof(Network, use_bpdu)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 275 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.PrefixAllowList",                config_parse_in_addr_prefixes,                            AF_INET6,                      offsetof(Network, ndisc_allow_listed_prefix)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 423 "../git/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinSchedulerClass.ClassId",     config_parse_tclass_classid,                              TCLASS_KIND_DRR,               0},
#line 82 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.MACSpoofCheck",                        config_parse_sr_iov_boolean,                              0,                             offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0},
#line 273 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouterAllowList",                config_parse_in_addr_prefixes,                            AF_INET6,                      offsetof(Network, ndisc_allow_listed_router)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 276 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.PrefixDenyList",                 config_parse_in_addr_prefixes,                            AF_INET6,                      offsetof(Network, ndisc_deny_listed_prefix)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 277 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouteAllowList",                 config_parse_in_addr_prefixes,                            AF_INET6,                      offsetof(Network, ndisc_allow_listed_route_prefix)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 274 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouterDenyList",                 config_parse_in_addr_prefixes,                            AF_INET6,                      offsetof(Network, ndisc_deny_listed_router)},
      {(char*)0}, {(char*)0},
#line 580 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.Quantum",         config_parse_fair_queueing_controlled_delay_size,         QDISC_KIND_FQ_CODEL,           0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 130 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6HopLimit",                        config_parse_int,                                         0,                             offsetof(Network, ipv6_hop_limit)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 334 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeMDB.MulticastGroupAddress",             config_parse_mdb_group_address,                           0,                             0},
      {(char*)0},
#line 331 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.VNI",                               config_parse_fdb_vxlan_vni,                               0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 86 "../git/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.MACAddress",                           config_parse_sr_iov_mac,                                  0,                             offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0},
#line 418 "../git/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.CEThresholdSec",              config_parse_controlled_delay_usec,                       QDISC_KIND_CODEL,              0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 375 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.DataSamplePoint",                         config_parse_permille,                                    0,                             offsetof(Network, can_data_sample_point)},
      {(char*)0}, {(char*)0},
#line 359 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.ValidLifetimeSec",                 config_parse_prefix_lifetime,                             0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 156 "../git/src/network/networkd-network-gperf.gperf"
      {"Address.DuplicateAddressDetection",           config_parse_duplicate_address_detection,                 0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 103 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.Xfrm",                                config_parse_stacked_netdev,                              NETDEV_KIND_XFRM,              offsetof(Network, stacked_netdev_names)},
      {(char*)0},
#line 485 "../git/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.MTUBytes",          config_parse_hierarchy_token_bucket_class_size,           TCLASS_KIND_HTB,               0},
#line 69 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.Group",                                  config_parse_link_group,                                  0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 77 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.RequiredFamilyForOnline",                config_parse_required_family_for_online,                  0,                             offsetof(Network, required_family_for_online)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 442 "../git/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueingClass.ClassId",              config_parse_tclass_classid,                              TCLASS_KIND_QFQ,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 554 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseTimezone",                            config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_timezone)},
#line 89 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.BatmanAdvanced",                      config_parse_ifname,                                      0,                             offsetof(Network, batadv_name)},
#line 540 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseDomainName",                          config_parse_dhcp_use_domains,                            AF_UNSPEC,                     0},
      {(char*)0},
#line 539 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseDomains",                             config_parse_dhcp_use_domains,                            AF_UNSPEC,                     0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 471 "../git/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.VirtualQueues",   config_parse_generic_random_early_detection_u32,          QDISC_KIND_GRED,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 468 "../git/src/network/networkd-network-gperf.gperf"
      {"FlowQueuePIE.PacketLimit",                    config_parse_fq_pie_packet_limit,                         QDISC_KIND_FQ_PIE,             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 519 "../git/src/network/networkd-network-gperf.gperf"
      {"/* backwards compatibility: do not add new entries to this section */"},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 561 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.RapidCommit",                          config_parse_warn_compat,                                 DISABLED_LEGACY,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 256 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.SendVendorOption",                     config_parse_dhcp_send_option,                            AF_INET6,                      offsetof(Network, dhcp6_client_send_vendor_options)},
      {(char*)0}, {(char*)0},
#line 195 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.InitialAdvertisedReceiveWindow",        config_parse_tcp_window,                                  0,                             0},
#line 160 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AddressLabel.Label",                      config_parse_address_label,                               0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 577 "../git/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Quantum",                        config_parse_fair_queueing_size,                          QDISC_KIND_FQ,                 0},
      {(char*)0}, {(char*)0},
#line 159 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AddressLabel.Prefix",                     config_parse_address_label_prefix,                        0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 204 "../git/src/network/networkd-network-gperf.gperf"
      {"NextHop.Family",                              config_parse_nexthop_family,                              0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 337 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeVLAN.VLAN",                             config_parse_brvlan_vlan,                                 0,                             0},
      {(char*)0}, {(char*)0},
#line 550 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.DUIDType",                               config_parse_network_duid_type,                           0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 74 "../git/src/network/networkd-network-gperf.gperf"
      {"Link.Unmanaged",                              config_parse_bool,                                        0,                             offsetof(Network, unmanaged)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 226 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.MUDURL",                               config_parse_mud_url,                                     0,                             offsetof(Network, dhcp_mudurl)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 107 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6LinkLocalAddressGenerationMode",  config_parse_ipv6_link_local_address_gen_mode,            0,                             offsetof(Network, ipv6ll_address_gen_mode)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 144 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6SendRA",                          config_parse_router_prefix_delegation,                    0,                             offsetof(Network, router_prefix_delegation)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 269 "../git/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseMTU",                         config_parse_bool,                                        0,                             offsetof(Network, ipv6_accept_ra_use_mtu)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 284 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.RelayAgentRemoteId",               config_parse_dhcp_server_relay_agent_suboption,           0,                             offsetof(Network, dhcp_server_relay_agent_remote_id)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 127 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6AcceptRA",                        config_parse_tristate,                                    0,                             offsetof(Network, ipv6_accept_ra)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 338 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeVLAN.EgressUntagged",                   config_parse_brvlan_untagged,                             0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 252 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.MUDURL",                               config_parse_mud_url,                                     0,                             offsetof(Network, dhcp6_mudurl)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 196 "../git/src/network/networkd-network-gperf.gperf"
      {"Route.TCPAdvertisedMaximumSegmentSize",       config_parse_tcp_advmss,                                  0,                             0},
      {(char*)0},
#line 126 "../git/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6PrivacyExtensions",               config_parse_ipv6_privacy_extensions,                     0,                             offsetof(Network, ipv6_privacy_extensions)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 258 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.WithoutRA",                            config_parse_dhcp6_client_start_mode,                     0,                             offsetof(Network, dhcp6_client_start_mode)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 335 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeMDB.VLANId",                            config_parse_mdb_vlan_id,                                 0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 373 "../git/src/network/networkd-network-gperf.gperf"
      {"CAN.SyncJumpWidth",                           config_parse_uint32,                                      0,                             offsetof(Network, can_sync_jump_width)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 557 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.ForceDHCPv6PDOtherInformation",          config_parse_warn_compat,                                 DISABLED_LEGACY,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 329 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.VLANId",                            config_parse_fdb_vlan_id,                                 0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 366 "../git/src/network/networkd-network-gperf.gperf"
      {"LLDP.MUDURL",                                 config_parse_mud_url,                                     0,                             offsetof(Network, lldp_mudurl)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 537 "../git/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseMTU",                                 config_parse_bool,                                        0,                             offsetof(Network, dhcp_use_mtu)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 332 "../git/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.AssociatedWith",                    config_parse_fdb_ntf_flags,                               0,                             0}
    };

  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      register unsigned int key = network_network_gperf_hash (str, len);

      if (key <= MAX_HASH_VALUE)
        {
          register const char *s = wordlist[key].section_and_lvalue;

          if (s && *str == *s && !strcmp (str + 1, s + 1))
            return &wordlist[key];
        }
    }
  return 0;
}
